@@ -3,7 +3,7 @@ BEGIN {
   $twigils::AUTHORITY = 'cpan:FLORA';
 }
 {
-  $twigils::VERSION = '0.02'; # TRIAL
+  $twigils::VERSION = '0.03'; # TRIAL
 }
 # ABSTRACT: Perl 6 style twigils for Perl 5
 
@@ -14,7 +14,7 @@ use XSLoader;
 use Carp 'croak';
 use Devel::CallChecker;
 use Devel::CallParser;
-use Exporter 'import';
+use Exporter ();
 
 our @EXPORT = map { "intro_twigil_${_}_var" } qw(my state our);
 
@@ -33,6 +33,15 @@ sub intro_twigil_our_var {
     croak "intro_twigil_our_var called as a function";
 }
 
+sub import {
+    if (defined $_[1] && $_[1] eq 'fatal_lookup_errors') {
+        $^H{__PACKAGE__ . '/not_in_pad_fatal'} = 1;
+        splice(@_, 1, 1, ());
+    }
+
+    goto &Exporter::import;
+}
+
 XSLoader::load(
     __PACKAGE__,
     exists $twigil::{VERSION} ? ${ $twigil::{VERSION} } : (),
